==> jtools-nodejs-1.2.15.tgz: package/DiaHora.js <==
"use strict";
var Texto = require('./Texto');
var moment = require('moment');
var DiaHora = /** @class */ (function () {
    function DiaHora(ano, mes, dia, hora, minuto, segundo) {
        this.ano = ano;
        this.mes = mes;
        this.dia = dia;
        this.hora = hora;
        this.minuto = minuto;
        this.segundo = segundo;
        this.anoFormatado = new Texto.Pad(4).padEsquerda(ano.toString());
        //...
        var _pad2 = new Texto.Pad(2);
        this.mesFormatado = _pad2.padEsquerda(mes.toString());
        this.diaFormatado = _pad2.padEsquerda(dia.toString());
        this.horaFormatada = _pad2.padEsquerda(hora.toString());
        this.minutoFormatado = _pad2.padEsquerda(minuto.toString());
        this.segundoFormatado = _pad2.padEsquerda(segundo.toString());
    }
    DiaHora.prototype.compacta = function () {
        return this.anoFormatado +
            this.mesFormatado +
            this.diaFormatado +
            this.horaFormatada +
            this.minutoFormatado +
            this.segundoFormatado;
    };
    DiaHora.prototype.toString = function () {
        return this.anoFormatado + "-" + this.mesFormatado + "-" + this.diaFormatado + " " + this.horaFormatada + ":" + this.minutoFormatado + ":" + this.segundoFormatado;
    };
    DiaHora.prototype.toDate = function () {
        return new Date(this.ano, this.mes, this.dia, this.hora, this.minuto, this.segundo, 0);
    };
    DiaHora.descompacta = function (valor) {
        //yyyyMMddhhmmss
        //01234567890123
        var _ano = Number(valor.substring(0, 4));
        var _mes = Number(valor.substring(4, 6));
        var _dia = Number(valor.substring(6, 8));
        var _hora = Number(valor.substring(8, 10));
        var _min = Number(valor.substring(10, 12));
        var _seg = Number(valor.substring(12));
        //======
        return new DiaHora(_ano, _mes, _dia, _hora, _min, _seg);
    };
    DiaHora.agora = function () {
        var _retorno = moment().format('YYYYMMDDHHmmss');
        return DiaHora.descompacta(_retorno);
    };
    return DiaHora;
}());
module.exports = DiaHora;

==> jtools-nodejs-1.4.0.tgz: package/DiaHora.js <==
var Texto = require('./Texto');
var moment = require('moment');

var DiaHora = (function () {
    function DiaHora(ano, mes, dia, hora, minuto, segundo) {
        this.ano = ano;
        this.mes = mes;
        this.dia = dia;
        this.hora = hora;
        this.minuto = minuto;
        this.segundo = segundo;
        this.anoFormatado = new Texto.Pad(4).padEsquerda(ano.toString());

        //...
        var _pad2 = new Texto.Pad(2);
        this.mesFormatado = _pad2.padEsquerda(mes.toString());
        this.diaFormatado = _pad2.padEsquerda(dia.toString());
        this.horaFormatada = _pad2.padEsquerda(hora.toString());
        this.minutoFormatado = _pad2.padEsquerda(minuto.toString());
        this.segundoFormatado = _pad2.padEsquerda(segundo.toString());
    }
    DiaHora.prototype.compacta = function () {
        return this.anoFormatado + this.mesFormatado + this.diaFormatado + this.horaFormatada + this.minutoFormatado + this.segundoFormatado;
    };
    DiaHora.prototype.toString = function () {
        return this.anoFormatado + '-' + this.mesFormatado + '-' + this.diaFormatado + ' ' + this.horaFormatada + ':' + this.minutoFormatado + ':' + this.segundoFormatado;
    };
    DiaHora.prototype.toDate = function () {
        return new Date(this.ano, this.mes, this.dia, this.hora, this.minuto, this.segundo, 0);
    };
    DiaHora.descompacta = function (valor) {
        //yyyyMMddhhmmss
        //01234567890123
        var _ano = Number(valor.substring(0, 4));
        var _mes = Number(valor.substring(4, 6));
        var _dia = Number(valor.substring(6, 8));
        var _hora = Number(valor.substring(8, 10));
        var _min = Number(valor.substring(10, 12));
        var _seg = Number(valor.substring(12));

        //======
        return new DiaHora(_ano, _mes, _dia, _hora, _min, _seg);
    };
    DiaHora.agora = function () {
        var _retorno = moment().format('YYYYMMDDHHmmss');
        return DiaHora.descompacta(_retorno);
    };
    return DiaHora;
})();

module.exports = DiaHora;
